summaryrefslogtreecommitdiff
path: root/src/radius_shell.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/radius_shell.c')
-rw-r--r--src/radius_shell.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/radius_shell.c b/src/radius_shell.c
index e7cffad..5da76dc 100644
--- a/src/radius_shell.c
+++ b/src/radius_shell.c
@@ -92,7 +92,7 @@ execit:
/*
* Eventually handle this program being linked or symlinked
* and that the shell is one of the shells in /etc/shells
* Expect it to be installed as /sbin/radius/vbash, etc.
*/
shell = strrchr(args[0], '/');
if (!shell)
@@ -110,11 +110,11 @@ execit:
/* should really check this against /etc/shell */
snprintf(execshell, sizeof execshell, "/bin/%s", check);
#else
- check = "vbash";
+ check = "bash";
if (*args[0] == '-')
- shell = "-vbash";
+ shell = "-bash";
else
- shell = "vbash";
+ shell = "bash";
snprintf(execshell, sizeof execshell, "/bin/%s", check);
#endif
@@ -92,7 +92,7 @@ execit:
* Eventually handle this program being linked or symlinked
* and that the shell is one of the shells in /etc/shells
- * Expect it to be installed as /sbin/radius/vbash, etc.
+ * Expect it to be installed as /sbin/radius/bash, etc.
*/
shell = strrchr(args[0], '/');